@@ -20,8 +20,12 @@ module func_adaptative
         double precision,intent(in)::thi,thj
         double precision::vsi,vti,res,ui !test
         double precision,dimension(:),allocatable::bh
-        double precision::wij
+        double precision::wij 
+        double precision,dimension(2)::k0bbb
         
+        if(.false.) then
+            k0bbb=k0 
+        end if 
         allocate(bh(np))
         !call dblepr("b(1) funcpafrailtyPred_ind 41", -1, b(1), 1)             
         bh(1)=b(1)
@@ -90,7 +94,7 @@ module func_adaptative
         double precision::vsi,vti,res,ui
         double precision,dimension(np)::bh
         !double precision::wij
-        double precision ::I1,c1,c2,integral
+        double precision ::I1,c1,c2
         double precision, dimension(:,:),allocatable::m1,m3  
         double precision, dimension(:,:),allocatable::m
         
@@ -281,7 +285,11 @@ module func_adaptative
         double precision,intent(in)::thi,thj
         double precision::vsi,vti,res,ui
         double precision,dimension(np)::bh
-         
+        double precision,dimension(2)::k0b
+
+
+        k0b=k0
+        
         do i=1,np
             bh(i)=b(i)
         end do
